# [HP名] ホームページ フロントエンド要件定義書
## ゴール: {prompt}

## 1. コンセプト
### 1.1 全体的なデザインコンセプト
### 1.2 レスポンシブルデザイン

## 2. ファイル・フォルダ構成
- Markdown形式で省略なしのファイル・フォルダ構成


## 3. 利用技術
- 以下は具体的な最新のフレームワークを提案すること

### 3.1 HTML
### 3.2 CSS
### 3.3 JavaScript
### 3.4 素材（画像、動画など）

## 4. UI構造

### 4.1 全体構成
図をASCII文字で描いてください。
ずの中身には項目番号を記載すること

### 4.2 ヘッダー
### 4.3 メインコンテンツ
#### 4.3.1 ヒーロー セクション
#### 4.3.2 機能説明セクション
#### 4.3.3 製品検索機能セクション
#### 4.3.4 テスティモニアル セクション
#### 4.3.5 ユーザー企業ロゴ セクション
#### 4.3.6 コール・トゥ・アクション セクション
### 4.4 フッター
- 必要な情報へのリンクを別々に配置